
.. If you created a package, create one automodule per module in the package.

API Reference
#############

.. automodule:: adafruit_circuitplayground.circuit_playground_base
   :members:

.. automodule:: adafruit_circuitplayground.bluefruit
  :members:

.. automodule:: adafruit_circuitplayground.express
   :members:
